@@ -10,4 +10,4 @@ curl ${CURL_OPTIONS:-} \
 	--data-urlencode "recfile=$6" \
 	--data-urlencode "uniq=$7" \
 	--data-urlencode "accountcode=$8" \
-	"https://ats2bx24.it-center.by/logger?ats=$klient"
+	"https://asterisk-connect.zruchna.io/?ats=$klient"
